@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 my $test = Test::Builder->new;
 
@@ -45,7 +45,7 @@ sub tidyall_ok {
     }
 
     unless (@files) {
-        $test->plan(1);
+        $test->plan( tests => 1 );
         $test->ok( 1, 'found no matching files for tidyall_ok' );
         return;
     }
@@ -92,7 +92,7 @@ tidyall
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
