@@ -1,7 +1,8 @@
 package Test::Code::TidyAll::Conf;
 
 use Code::TidyAll;
-use Code::TidyAll::Util qw(dirname tempdir_simple write_file);
+use Code::TidyAll::Util qw(dirname tempdir_simple);
+use File::Slurp::Tiny qw(read_file write_file);
 use Test::Class::Most parent => 'Code::TidyAll::Test::Class';
 
 my $conf1;
